@@ -1,4 +1,4 @@
-"""Functions to translate from Ladybug geomtries to Rhino geometries."""
+"""Functions to translate from Ladybug geometries to Rhino geometries."""
 from .config import tolerance
 from .color import color_to_color, gray
 
@@ -38,8 +38,8 @@ def from_linesegment2d(line, z=0):
 
 def from_arc2d(arc, z=0):
     """Rhino Arc from ladybug Arc2D."""
-    circle = rg.Circle(from_point2d(arc.c, z), arc.r)
-    return rg.Arc(circle, rg.Interval(arc.a1, arc.a2))
+    pts = (arc.p1, arc.midpoint, arc.p2)
+    return rg.Arc(*(from_point2d(pt) for pt in pts))
 
 
 def from_polygon2d(polygon, z=0):
@@ -148,6 +148,22 @@ def from_polyface3d(polyface):
         return brep[0]
 
 
+def from_sphere(sphere):
+    """Rhino Sphere from ladybug Sphere."""
+    return rg.Sphere(from_point3d(sphere.center), sphere.radius)
+
+
+def from_cone(cone):
+    """Rhino Cone from ladybug Cone."""
+    plane = rg.Plane(from_point3d(cone.vertex), from_vector3d(cone.axis.normalize()))
+    return rg.Cone(plane, cone.height, cone.radius)
+
+
+def from_cylinder(cylinder):
+    """Rhino Cone from ladybug Cone."""
+    return rg.Cylinder(from_arc3d(cylinder.base_bottom), cylinder.height)
+
+
 """________ADDITIONAL 3D GEOMETRY TRANSLATORS________"""
 
 
@@ -261,6 +277,17 @@ def from_mesh2d_to_outline(mesh, z=0):
     return face_plines
 
 
+def from_mesh3d_to_outline(mesh):
+    """Rhino Mesh and Polylines from the ladybug Mesh3D.
+
+    Returns:
+        A tuple with two items - a Rhino Mesh first followed by outline curves
+        of the Mesh.
+    """
+    rh_mesh = from_mesh3d(mesh)
+    return rh_mesh, rh_mesh.GetNakedEdges()
+
+
 """________________EXTRA HELPER FUNCTIONS________________"""
 
 
